@@ -40,10 +40,11 @@ class CommonTools(BaseTools):
     ) -> Optional[T]:
         """
         Returns the value of a function or None if it raised an exception.
-        :param function: Try calling this function
-        :param fail_val: Return this value
-        :param exception: Restrict caught exceptions to subclasses of this type
-        :return:
+
+        Args:
+            function: Try calling this function
+            fail_val: Return this value
+            exception: Restrict caught exceptions to subclasses of this type
         """
         try:
             return function()
@@ -58,7 +59,7 @@ class CommonTools(BaseTools):
     @classmethod
     def or_null(cls, x: Any, dtype=lambda s: s, or_else: Any = None) -> Optional[Any]:
         """
-        Return `None` if the operation `dtype` on `x` failed; returns the result otherwise.
+        Return ``None`` if the operation ``dtype`` on ``x`` failed; returns the result otherwise.
         """
         return or_else if cls.is_null(x) else dtype(x)
 
@@ -70,7 +71,7 @@ class CommonTools(BaseTools):
         or_else: Union[None, BaseException, Type[BaseException]] = None,
     ) -> Any:
         """
-        Returns `dtype(x)` if `x` is not None, or raises `or_else`.
+        Returns ``dtype(x)`` if ``x`` is not None, or raises ``or_else``.
         """
         if or_else is None:
             or_else = LookupError("Value is {}".format(x))
@@ -83,10 +84,12 @@ class CommonTools(BaseTools):
     @classmethod
     def iterator_has_elements(cls, x: Iterator[Any]) -> bool:
         """
-        Returns False `next(x)` raises a `StopIteration`.
-        WARNING: Tries to call `next(x)`, progressing iterators. Don't use `x` after calling this.
-        Note that calling `iterator_has_elements([5])` will raise a `TypeError`
-        :param x: Must be an Iterator
+        Returns False iff ``next(x)`` raises a ``StopIteration``.
+        WARNING: Tries to call ``next(x)``, progressing iterators. Don't use ``x`` after calling this.
+        Note that calling ``iterator_has_elements([5])`` will raise a `TypeError`
+
+        Args:
+            x: Must be an Iterator
         """
         return cls.succeeds(lambda: next(x), StopIteration)
 
@@ -111,8 +114,10 @@ class CommonTools(BaseTools):
             - x is None
             - np.is_nan(x)
             - x is something with 0 length
-            - x is iterable and has 0 elements (will call `__iter__`)
-        :raises RefusingRequestError If `x` is an Iterator. Calling this would empty the iterator, which is dangerous.
+            - x is iterable and has 0 elements (will call ``__iter__``)
+
+        Raises:
+            RefusingRequestError If ``x`` is an Iterator. Calling this would empty the iterator, which is dangerous.
         """
         if isinstance(x, Iterator):
             raise RefusingRequestError("Do not call is_empty on an iterator.")
@@ -134,10 +139,12 @@ class CommonTools(BaseTools):
             - x is None
             - np.is_nan(x)
             - x is something with 0 length
-            - x is iterable and has 0 elements (will call `__iter__`)
+            - x is iterable and has 0 elements (will call ``__iter__``)
             - a str(x) is 'nan', 'null', or 'none'; case-insensitive
         In contrast to is_nan, also returns True if x==''.
-        :raises TypeError If `x` is an Iterator. Calling this would empty the iterator, which is dangerous.
+
+        Raises:
+            TypeError If ``x`` is an Iterator. Calling this would empty the iterator, which is dangerous.
         """
         return cls.is_empty(x) or str(x).lower() in ["nan", "null", "none"]
 
@@ -145,8 +152,12 @@ class CommonTools(BaseTools):
     def unique(cls, sequence: Iterable[T]) -> Sequence[T]:
         """
         Returns the unique items in `sequence`, in the order they appear in the iteration.
-        :param sequence: Any once-iterable sequence
-        :return: An ordered List of unique elements
+
+        Args:
+            sequence: Any once-iterable sequence
+
+        Returns:
+            An ordered List of unique elements
         """
         seen = set()
         return [x for x in sequence if not (x in seen or seen.add(x))]
@@ -154,15 +165,20 @@ class CommonTools(BaseTools):
     @classmethod
     def first(cls, collection: Iterable[Any], attr: Optional[str] = None) -> Optional[Any]:
         """
+        Gets the first element.
+
+        WARNING: Tries to call ``next(x)``, progressing iterators.
+
+        Args:
+            collection: Any iterable
+            attr: The name of the attribute that might be defined on the elements,
+                or None to indicate the elements themselves should be used
+
         Returns:
-            - The attribute of the first element if `attr` is defined on an element
+            - The attribute of the first element if ``attr`` is defined on an element
             - None if the the sequence is empty
-            - None if the sequence has no attribute `attr`
-        WARNING: Tries to call `next(x)`, progressing iterators.
-        :param collection: Any iterable
-        :param attr: The name of the attribute that might be defined on the elements,
-        or None to indicate the elements themselves should be used
-        :return: The first element, or None
+            - None if the sequence has no attribute ``attr``
+
         """
         try:
             # note: calling iter on an iterator creates a view only
@@ -174,10 +190,11 @@ class CommonTools(BaseTools):
     @classmethod
     def iter_rowcol(cls, n_rows: int, n_cols: int) -> Generator[Tuple[int, int], None, None]:
         """
-        An iterator over (row column) pairs for a row-first traversal of a grid with `n_cols` columns.
-        Ex:
-            it = CommonTools.iter_rc(5, 3)
-            [next(it) for _ in range(5)]  # [(0,0),(0,1),(0,2),(1,0),(1,1)]
+        An iterator over (row column) pairs for a row-first traversal of a grid with ``n_cols`` columns.
+
+        Example:
+            >>> it = CommonTools.iter_rowcol(5, 3)
+            >>> [next(it) for _ in range(5)]  # [(0,0),(0,1),(0,2),(1,0),(1,1)]
         """
         for i in range(n_rows * n_cols):
             yield i // n_cols, i % n_cols
@@ -190,10 +207,12 @@ class CommonTools(BaseTools):
         skip_none: bool = False,
     ) -> Mapping[Y, Sequence[Z]]:
         """
-        Builds a mapping of some attribute in `sequence` to the containing elements of `sequence`.
-        :param sequence: Any iterable
-        :param key_attr: Usually string like 'attr1.attr2'; see `look`
-        :param skip_none: If None, raises a `KeyError` if the key is missing for any item; otherwise, skips it
+        Builds a mapping of some attribute in `sequence` to the containing elements of ``sequence``.
+
+        Args:
+            sequence: Any iterable
+            key_attr: Usually string like 'attr1.attr2'; see `look`
+            skip_none: If None, raises a `KeyError` if the key is missing for any item; otherwise, skips it
         """
         dct = defaultdict(lambda: [])
         for item in sequence:
@@ -208,8 +227,12 @@ class CommonTools(BaseTools):
     def mem_size(cls, obj) -> str:
         """
         Returns the size of the object in memory as a human-readable string.
-        :param obj: Any Python object
-        :return: A human-readable size with units
+
+        Args:
+            obj: Any Python object
+
+        Returns:
+            A human-readable size with units
         """
         return nicesize(sys.getsizeof(obj))
 
@@ -217,11 +240,10 @@ class CommonTools(BaseTools):
     def devnull(cls):
         """
         Yields a 'writer' that does nothing.
-        Ex:
-        ```
-            with Tools.devnull() as devnull:
-                devnull.write('hello')
-        ```
+
+        Example:
+            >>> with CommonTools.devnull() as devnull:
+            >>>     devnull.write('hello')
         """
         yield DevNull()
 
@@ -229,7 +251,9 @@ class CommonTools(BaseTools):
     def parse_bool(cls, s: str) -> bool:
         """
         Parses a 'true'/'false' string to a bool, ignoring case.
-        :raises: XValueError If neither true nor false
+
+        Raises:
+            ValueError: If neither true nor false
         """
         if isinstance(s, bool):
             return s
